@@ -318,16 +318,6 @@ QList<T> map(const QList<S>& list, std::function<T(S)> transformer)
     return result;
 }
 
-template <class S, class T>
-QHash<S, T> toHash(const QList<S>& list, std::function<T(S)> transformer)
-{
-    QHash<S, T> result;
-    for (const S& el : list)
-        result[el] = transformer(el);
-
-    return result;
-}
-
 template <class S, class T>
 QSet<T> map(const QSet<S>& set, std::function<T(S)> transformer)
 {
@@ -338,6 +328,26 @@ QSet<T> map(const QSet<S>& set, std::function<T(S)> transformer)
     return result;
 }
 
+template <class K, class V>
+QHash<K, V> toHash(const QList<V>& list, std::function<K(V)> transformer)
+{
+    QHash<K, V> result;
+    for (const V& el : list)
+        result[transformer(el)] = el;
+
+    return result;
+}
+
+template <class K, class V>
+QHash<K, V> toHash(const QSet<V>& list, std::function<K(V)> transformer)
+{
+    QHash<K, V> result;
+    for (const V& el : list)
+        result[transformer(el)] = el;
+
+    return result;
+}
+
 template <class T>
 void removeDuplicates(QList<T>& list)
 {
