@@ -1,6 +1,9 @@
 #include "completionhelper.h"
 #include "completioncomparer.h"
 #include "db/db.h"
+#include "parser/ast/sqlitedelete.h"
+#include "parser/ast/sqliteinsert.h"
+#include "parser/ast/sqliteupdate.h"
 #include "parser/keywords.h"
 #include "parser/parser.h"
 #include "parser/lexer.h"
@@ -147,6 +150,7 @@ QList<ExpectedTokenPtr> CompletionHelper::getExpectedTokens(TokenPtr token)
     switch (token->type)
     {
         case Token::CTX_ROWID_KW:
+        case Token::CTX_STRICT_KW:
             results += getExpectedToken(ExpectedToken::KEYWORD, token->value);
             break;
         case Token::CTX_NEW_KW:
@@ -253,13 +257,13 @@ QList<ExpectedTokenPtr> CompletionHelper::getExpectedTokens(TokenPtr token)
             results += getExpectedToken(ExpectedToken::OTHER, QString(), QString(), tr("Any word"));
             break;
         case Token::STRING:
-            results += getExpectedToken(ExpectedToken::STRING);
+            results += getExpectedToken(ExpectedToken::STRING, "''", QString(), tr("String"));
             break;
         case Token::FLOAT:
-            results += getExpectedToken(ExpectedToken::NUMBER);
+            results += getExpectedToken(ExpectedToken::NUMBER, QString(), QString(), tr("Number"));
             break;
         case Token::INTEGER:
-            results += getExpectedToken(ExpectedToken::NUMBER);
+            results += getExpectedToken(ExpectedToken::NUMBER, QString(), QString(), tr("Number"));
             break;
         case Token::OPERATOR:
             results += getExpectedToken(ExpectedToken::OPERATOR, token->value);
@@ -271,7 +275,7 @@ QList<ExpectedTokenPtr> CompletionHelper::getExpectedTokens(TokenPtr token)
             results += getExpectedToken(ExpectedToken::OPERATOR, ")");
             break;
         case Token::BLOB:
-            results += getExpectedToken(ExpectedToken::BLOB);
+            results += getExpectedToken(ExpectedToken::BLOB, "X''", QString(), tr("BLOB literal"));
             break;
         case Token::KEYWORD:
             results += getExpectedToken(ExpectedToken::KEYWORD, token->value);
@@ -497,6 +501,16 @@ QList<ExpectedTokenPtr> CompletionHelper::getObjects(ExpectedToken::Type type, c
 QList<ExpectedTokenPtr> CompletionHelper::getColumns()
 {
     QList<ExpectedTokenPtr> results;
+    switch (context) {
+        case Context::UPDATE_RETURNING:
+        case Context::INSERT_RETURNING:
+        case Context::DELETE_RETURNING:
+            results += getExpectedToken(ExpectedToken::OPERATOR, "*", QString(), QString(), 1);
+            break;
+        default:
+            break;
+    }
+
     if (previousId)
     {
         if (twoIdsBack)
@@ -620,6 +634,9 @@ QList<ExpectedTokenPtr> CompletionHelper::getColumns(const QString &prefixTable)
         label = prefixTable+" = "+table;
     }
 
+    if (!dbName.isNull())
+        dbName = translateDatabase(dbName);
+
     // CREATE TRIGGER has a special "old" and "new" keywords as aliases for deleted/inserted/updated rows.
     // They should refer to a table that the trigger is created for.
     QString tableLower = table;
@@ -896,6 +913,7 @@ void CompletionHelper::filterOtherId(QList<ExpectedTokenPtr> &resultsSoFar, cons
             case Token::CTX_FK_MATCH:
             case Token::CTX_PRAGMA:
             case Token::CTX_ROWID_KW:
+            case Token::CTX_STRICT_KW:
             case Token::CTX_NEW_KW:
             case Token::CTX_OLD_KW:
             case Token::CTX_ERROR_MESSAGE:
@@ -1023,14 +1041,23 @@ void CompletionHelper::extractPreviousIdTokens(const TokenList &parsedTokens)
 
 void CompletionHelper::extractQueryAdditionalInfo()
 {
+    // Even if we're in a SELECT, it might be just a child part of INSERT INTO x SELECT ...
+    // or it may be UPDATE x SET y FROM other source.
+    // Because of that we extract all INSERT/DELETE/UPDATE aliases no matter if cursor is in the selectCore or not.
+    extractTableAliasMapFromOtherQueries();
+
+    extractUpdateFromColumnsAndTables();
+
     if (extractSelectCore())
     {
         extractSelectAvailableColumnsAndTables();
-        extractTableAliasMap();
+        extractSelectTableAliasMap();
         removeDuplicates(parentSelectAvailableColumns);
         detectSelectContext();
+        return;
     }
-    else if (isInUpdateColumn())
+
+    if (isInUpdateColumn())
     {
         context = Context::UPDATE_COLUMN;
     }
@@ -1055,6 +1082,25 @@ void CompletionHelper::extractQueryAdditionalInfo()
     {
         context = Context::EXPR;
     }
+    else if (isInInsertColumns())
+    {
+        context = Context::INSERT_COLUMNS;
+    }
+    else if (isInUpdateReturning())
+    {
+        context = Context::UPDATE_RETURNING;
+        extractUpdateAvailableColumnsAndTables();
+    }
+    else if (isInInsertReturning())
+    {
+        context = Context::INSERT_RETURNING;
+        extractInsertAvailableColumnsAndTables();
+    }
+    else if (isInDeleteReturning())
+    {
+        context = Context::DELETE_RETURNING;
+        extractDeleteAvailableColumnsAndTables();
+    }
 }
 
 void CompletionHelper::detectSelectContext()
@@ -1076,6 +1122,44 @@ void CompletionHelper::detectSelectContext()
     }
 }
 
+void CompletionHelper::extractTableAliasMapFromOtherQueries()
+{
+    if (!parsedQuery)
+        return;
+
+    SqliteQueryWithAliasedTablePtr queryWithAliasedTable = parsedQuery.dynamicCast<SqliteQueryWithAliasedTable>();
+    if (!queryWithAliasedTable)
+        return;
+
+    QString database = queryWithAliasedTable->getDatabase();
+    QString table = queryWithAliasedTable->getTable();
+    QString alias = queryWithAliasedTable->getTableAlias();
+    if (!alias.isNull() && !tableToAlias[table].contains(alias))
+    {
+        tableToAlias[table] += alias;
+        aliasToTable[alias] = Table(database, table);
+    }
+}
+
+void CompletionHelper::extractUpdateFromColumnsAndTables()
+{
+    if (!parsedQuery)
+        return;
+
+    SqliteUpdatePtr update = parsedQuery.objectCast<SqliteUpdate>();
+    if (!update || !update->from)
+        return;
+
+    for (const SelectResolver::Table& table : selectResolver->resolveTables(update->from))
+    {
+        if (!table.tableAlias.isNull() && !tableToAlias[table.table].contains(table.tableAlias))
+        {
+            tableToAlias[table.table] += table.tableAlias;
+            aliasToTable[table.tableAlias] = Table(table.database, table.table);
+        }
+    }
+}
+
 bool CompletionHelper::isInUpdateColumn()
 {
     // We will never get here if the subquery SELECT was used anywhere in the query,
@@ -1134,6 +1218,44 @@ bool CompletionHelper::isInCreateTrigger()
     return true;
 }
 
+bool CompletionHelper::isInUpdateReturning()
+{
+    return isIn(SqliteQueryType::Update, "returning", "RETURNING");
+}
+
+bool CompletionHelper::isInDeleteReturning()
+{
+    return isIn(SqliteQueryType::Delete, "returning", "RETURNING");
+}
+
+bool CompletionHelper::isInInsertReturning()
+{
+    return isIn(SqliteQueryType::Insert, "returning", "RETURNING");
+}
+
+bool CompletionHelper::isInInsertColumns()
+{
+    if (isIn(SqliteQueryType::Insert, "idlist_opt", QString()))
+        return true;
+
+    if (!parsedQuery)
+        return false;
+
+    if (parsedQuery->queryType != SqliteQueryType::Insert)
+        return false;
+
+    if (parsedQuery->tokensMap.contains("rp_opt"))
+    {
+        TokenList rpTokens = parsedQuery->tokensMap["rp_opt"];
+        if (rpTokens.isEmpty())
+            return parsedQuery->tokensMap["LP"][0]->start <= cursorPosition;
+        else
+            return rpTokens[0]->start >= cursorPosition;
+    }
+
+    return false;
+}
+
 bool CompletionHelper::isIn(SqliteQueryType queryType, const QString &tokenMapKey, const QString &prefixKeyword)
 {
     if (!parsedQuery)
@@ -1266,7 +1388,8 @@ void CompletionHelper::initFunctions(Db* db)
                      << "lag(expr)" << "lag(expr, offset)" << "lag(expr, offset, default)"
                      << "lead(expr)" << "lead(expr, offset)" << "lead(expr, offset, default)"
                      << "first_value(expr)" << "last_value(expr)" << "nth_value(expr, N)"
-                     << "substring(X,Y,Z)" << "substring(X,Y)";
+                     << "substring(X,Y,Z)" << "substring(X,Y)" << "unixepoch(mod,mod,...)"
+                     << "printf(format,...)" << "format(format,...)";
 
     if (!db->isOpen())
         return;
@@ -1274,7 +1397,7 @@ void CompletionHelper::initFunctions(Db* db)
     // Parse what we already have
     QSet<QString> handledSignatures;
     static_qstring(sigTpl, "%1_%2");
-    for (const QString& fn : sqlite3Functions)
+    for (QString& fn : sqlite3Functions)
     {
         int argStart = fn.lastIndexOf("(");
         int argEnd = fn.lastIndexOf(")");
@@ -1405,9 +1528,42 @@ void CompletionHelper::extractSelectAvailableColumnsAndTables()
     }
 }
 
-void CompletionHelper::extractTableAliasMap()
+void CompletionHelper::extractInsertAvailableColumnsAndTables()
 {
-    for (SelectResolver::Column column : selectAvailableColumns)
+    auto insert = parsedQuery.dynamicCast<SqliteInsert>();
+    extractAvailableColumnsAndTables(insert->database, insert->table);
+}
+
+void CompletionHelper::extractDeleteAvailableColumnsAndTables()
+{
+    auto del = parsedQuery.dynamicCast<SqliteDelete>();
+    extractAvailableColumnsAndTables(del->database, del->table);
+}
+
+void CompletionHelper::extractUpdateAvailableColumnsAndTables()
+{
+    auto update = parsedQuery.dynamicCast<SqliteUpdate>();
+    theFromAvailableColumns = selectResolver->resolveAvailableColumns(update->from);
+    theFromAvailableTables = selectResolver->resolveTables(update->from);
+}
+
+void CompletionHelper::extractAvailableColumnsAndTables(const QString& database, const QString& table)
+{
+    QStringList columnNames = schemaResolver->getTableColumns(database, table);
+    for (QString& colName : columnNames) {
+        SelectResolver::Column column;
+        column.type = SelectResolver::Column::COLUMN;
+        column.database = database;
+        column.table = table;
+        column.column = colName;
+        theFromAvailableColumns << column;
+        theFromAvailableTables << column.getTable();
+    }
+}
+
+void CompletionHelper::extractSelectTableAliasMap()
+{
+    for (SelectResolver::Column& column : selectAvailableColumns)
     {
         if (column.type != SelectResolver::Column::COLUMN)
             continue;
@@ -1423,7 +1579,7 @@ void CompletionHelper::extractTableAliasMap()
     // Given the above, we can extract table aliases in an order from deepest
     // to shallowest, skipping any duplicates, becase the deeper alias is mentioned,
     // the higher is its priority.
-    for (SelectResolver::Column column : parentSelectAvailableColumns)
+    for (SelectResolver::Column& column : parentSelectAvailableColumns)
     {
         if (column.type != SelectResolver::Column::COLUMN)
             continue;
@@ -1445,7 +1601,7 @@ void CompletionHelper::extractCreateTableColumns()
         return;
 
     SqliteCreateTablePtr createTable = parsedQuery.dynamicCast<SqliteCreateTable>();
-    for (SqliteCreateTable::Column* col : createTable->columns)
+    for (SqliteCreateTable::Column*& col : createTable->columns)
         favoredColumnNames << col->name;
 }
 
