@@ -67,9 +67,10 @@ bool AbstractDb::openQuiet()
 
 bool AbstractDb::closeQuiet()
 {
-    QWriteLocker locker(&dbOperLock);
     QWriteLocker connectionLocker(&connectionStateLock);
     interruptExecution();
+
+    QWriteLocker locker(&dbOperLock);
     bool res = closeInternal();
     clearAttaches();
     registeredFunctions.clear();
@@ -509,6 +510,51 @@ bool AbstractDb::isCollationRegistered(const QString& name)
     return registeredCollations.contains(name);
 }
 
+bool AbstractDb::beginNoLock()
+{
+    if (!isOpenInternal())
+        return false;
+
+    SqlQueryPtr results = exec("BEGIN;", Flag::NO_LOCK);
+    if (results->isError())
+    {
+        qCritical() << "Error while starting a transaction: " << results->getErrorCode() << results->getErrorText();
+        return false;
+    }
+
+    return true;
+}
+
+bool AbstractDb::commitNoLock()
+{
+    if (!isOpenInternal())
+        return false;
+
+    SqlQueryPtr results = exec("COMMIT;", Flag::NO_LOCK);
+    if (results->isError())
+    {
+        qCritical() << "Error while committing a transaction: " << results->getErrorCode() << results->getErrorText();
+        return false;
+    }
+
+    return true;
+}
+
+bool AbstractDb::rollbackNoLock()
+{
+    if (!isOpenInternal())
+        return false;
+
+    SqlQueryPtr results = exec("ROLLBACK;", Flag::NO_LOCK);
+    if (results->isError())
+    {
+        qCritical() << "Error while rolling back a transaction: " << results->getErrorCode() << results->getErrorText();
+        return false;
+    }
+
+    return true;
+}
+
 QHash<QString, QVariant> AbstractDb::getAggregateContext(void* memPtr)
 {
     if (!memPtr)
@@ -792,55 +838,31 @@ quint32 AbstractDb::generateAsyncId()
     return asyncId++;
 }
 
-bool AbstractDb::begin()
+bool AbstractDb::begin(bool noLock)
 {
+    if (noLock)
+        return beginNoLock();
+
     QWriteLocker locker(&dbOperLock);
-
-    if (!isOpenInternal())
-        return false;
-
-    SqlQueryPtr results = exec("BEGIN;", Flag::NO_LOCK);
-    if (results->isError())
-    {
-        qCritical() << "Error while starting a transaction: " << results->getErrorCode() << results->getErrorText();
-        return false;
-    }
-
-    return true;
+    return beginNoLock();
 }
 
-bool AbstractDb::commit()
+bool AbstractDb::commit(bool noLock)
 {
+    if (noLock)
+        return commitNoLock();
+
     QWriteLocker locker(&dbOperLock);
-
-    if (!isOpenInternal())
-        return false;
-
-    SqlQueryPtr results = exec("COMMIT;", Flag::NO_LOCK);
-    if (results->isError())
-    {
-        qCritical() << "Error while committing a transaction: " << results->getErrorCode() << results->getErrorText();
-        return false;
-    }
-
-    return true;
+    return commitNoLock();
 }
 
-bool AbstractDb::rollback()
+bool AbstractDb::rollback(bool noLock)
 {
+    if (noLock)
+        return rollbackNoLock();
+
     QWriteLocker locker(&dbOperLock);
-
-    if (!isOpenInternal())
-        return false;
-
-    SqlQueryPtr results = exec("ROLLBACK;", Flag::NO_LOCK);
-    if (results->isError())
-    {
-        qCritical() << "Error while rolling back a transaction: " << results->getErrorCode() << results->getErrorText();
-        return false;
-    }
-
-    return true;
+    return rollbackNoLock();
 }
 
 void AbstractDb::interrupt()
@@ -915,7 +937,15 @@ void AbstractDb::registerFunction(const AbstractDb::RegisteredFunction& function
 
 void AbstractDb::flushWal()
 {
-    if (!flushWalInternal())
+    if (flushWalInternal())
+    {
+        if (exec("PRAGMA journal_mode")->getSingleCell().toString() == "wal")
+        {
+            exec("PRAGMA journal_mode = delete;", Flag::ZERO_TIMEOUT);
+            exec("PRAGMA journal_mode = wal;", Flag::ZERO_TIMEOUT);
+        }
+    }
+    else
         notifyWarn(tr("Failed to make full WAL checkpoint on database '%1'. Error returned from SQLite engine: %2").arg(name, getErrorTextInternal()));
 }
 
