@@ -177,6 +177,10 @@ class API_EXPORT QueryExecutor : public QObject, public QRunnable
                                * The data cell comes from a VIEW that was not expanded (because there were
                                * multi-level views), therefore it was impossible to get ROWID for the cell.
                                */
+            RES_INLINE_SUBSEL,/**<
+                               * The data cell comes from an subselect used as inline expression of result column.
+                               * Getting ROWID of such cell is not possible.
+                               */
         };
 
         /**
@@ -1224,17 +1228,14 @@ class API_EXPORT QueryExecutor : public QObject, public QRunnable
 
         /**
          * @brief Extracts counting query results.
-         * @param asyncId Asynchronous ID of the counting query execution.
          * @param results Results from the counting query execution.
-         * @return true if passed asyncId is the one for currently running counting query, or false otherwise.
-         *
-         * It's called from database asynchronous execution thread. The database might have executed
-         * some other acynchronous queries too, so this method checks if the asyncId is the expected one.
+         * @return true if counting was successful, i.e. there is no ongoing query execution, or false otherwise.
          *
+         * It may be called from database asynchronous execution thread.
          * Basicly this method is called a result of countResults() call. Extracts counted number of rows
          * and stores it in query executor's context.
          */
-        bool handleRowCountingResults(quint32 asyncId, SqlQueryPtr results);
+        bool handleRowCountingResults(SqlQueryPtr results);
 
         QStringList applyFiltersAndLimitAndOrderForSimpleMethod(const QStringList &queries);
 
@@ -1384,14 +1385,6 @@ class API_EXPORT QueryExecutor : public QObject, public QRunnable
          */
         qint64 simpleExecutionStartTime;
 
-        /**
-         * @brief Asynchronous ID of counting query execution.
-         *
-         * Asynchronous ID returned from Db::asyncExec() for the counting query execution.
-         * See countResults() for details on counting query.
-         */
-        quint32 resultsCountingAsyncId = 0;
-
         /**
          * @brief Flag indicating results preloading.
          *
@@ -1494,6 +1487,8 @@ class API_EXPORT QueryExecutor : public QObject, public QRunnable
 
         bool forceSimpleMode = false;
         ChainExecutor* simpleExecutor = nullptr;
+        Db* countingDb = nullptr;
+        QStringList countingAttaches;
 
     signals:
         /**
@@ -1581,17 +1576,6 @@ class API_EXPORT QueryExecutor : public QObject, public QRunnable
          * In case of success emits executionFinished(), in case of error emits executionFailed().
          */
         void simpleExecutionFinished(SqlQueryPtr results);
-
-        /**
-         * @brief Handles asynchronous database execution results.
-         * @param asyncId Asynchronous ID of the execution.
-         * @param results Results from the execution.
-         *
-         * QueryExecutor checks whether the \p asyncId belongs to the counting query execution,
-         * or the simple execution.
-         * Dispatches query results to a proper handler method.
-         */
-        void dbAsyncExecFinished(quint32 asyncId, SqlQueryPtr results);
 };
 
 int qHash(QueryExecutor::EditionForbiddenReason reason);
