@@ -11,6 +11,8 @@ class SqliteIndexedColumn;
 
 class API_EXPORT SqliteCreateView : public SqliteQuery, public SqliteDdlWithDbContext
 {
+    Q_OBJECT
+
     public:
         SqliteCreateView();
         SqliteCreateView(const SqliteCreateView& other);
@@ -23,6 +25,7 @@ class API_EXPORT SqliteCreateView : public SqliteQuery, public SqliteDdlWithDbCo
         void setTargetDatabase(const QString& database);
         QString getObjectName() const;
         void setObjectName(const QString& name);
+        TokenList equivalentSelectTokens() const;
 
         bool tempKw = false;
         bool temporaryKw = false;
