@@ -65,6 +65,8 @@ class GUI_API_EXPORT SqlQueryModel : public QStandardItemModel
         bool isExecutionInProgress() const;
         StrHash<QString> attachDependencyTables();
         void detachDependencyTables();
+        void rememberFocusedCell();
+        void forgetFocusedCell();
 
         /**
          * @brief Disables or re-enables async query execution
@@ -244,6 +246,18 @@ class GUI_API_EXPORT SqlQueryModel : public QStandardItemModel
                 int argSquence = 0;
         };
 
+        struct StoredFocus
+        {
+            int row = -1;
+            int column = -1;
+            int forPage = -1;
+            int forRowsPerPage = -1;
+            QString forFilter;
+
+            bool isValid();
+            void reset();
+        };
+
         /**
          * @brief commitAddedRow Inserts new row to a table.
          * @param itemsInRow All cells for the new row.
@@ -303,10 +317,9 @@ class GUI_API_EXPORT SqlQueryModel : public QStandardItemModel
         SqlQueryModelColumnPtr getColumnModel(const QString& table, const QString& column);
         QList<SqlQueryModelColumnPtr> getTableColumnModels(const QString& database, const QString& table);
         QList<SqlQueryModelColumnPtr> getTableColumnModels(const QString& table);
-        void updateItem(SqlQueryItem* item, const QVariant& value, int columnIndex, const RowId& rowId, SqlResultsRowPtr row,
-                        const QStringList& columnNames, const BiStrHash& typeColumnToResColumn);
-        void updateItem(SqlQueryItem* item, const QVariant& value, int columnIndex, const RowId& rowId);
-        void updateItem(SqlQueryItem* item, const QVariant& value, int columnIndex, const RowId& rowId, Qt::Alignment alignment);
+        void updateItem(SqlQueryItem* item, const QVariant& value, const SqlQueryModelColumnPtr &column, const RowId& rowId, SqlResultsRowPtr row, const BiStrHash& typeColumnToResColumn);
+        void updateItem(SqlQueryItem* item, const QVariant& value, const SqlQueryModelColumnPtr &column, const RowId& rowId);
+        void updateItem(SqlQueryItem* item, const QVariant& value, const SqlQueryModelColumnPtr &column, const RowId& rowId, Qt::Alignment alignment);
         RowId getNewRowId(const RowId& currentRowId, const QList<SqlQueryItem*> items);
         void updateRowIdForAllItems(const AliasedTable& table, const RowId& rowId, const RowId& newRowId);
         QHash<QString, QVariantList> toValuesGroupedByColumns(const QList<SqlQueryItem*>& items);
@@ -316,6 +329,7 @@ class GUI_API_EXPORT SqlQueryModel : public QStandardItemModel
         QueryExecutor* queryExecutor = nullptr;
         Db* db = nullptr;
         QList<SqlQueryModelColumnPtr> columns;
+        StoredFocus storedFocus;
 
         /**
          * @brief tablesInUse
@@ -354,8 +368,8 @@ class GUI_API_EXPORT SqlQueryModel : public QStandardItemModel
          */
         bool loadData(SqlQueryPtr results);
 
-        QList<QStandardItem*> loadRow(SqlResultsRowPtr row, SqlQueryPtr results);
-        RowId getRowIdValue(SqlResultsRowPtr row, int columnIdx);
+        QList<QStandardItem*> loadRow(SqlResultsRowPtr row);
+        RowId getRowIdValue(SqlResultsRowPtr row, const SqlQueryModelColumnPtr &column);
         bool readColumns();
         void readColumnDetails();
         void updateColumnsHeader();
@@ -363,8 +377,6 @@ class GUI_API_EXPORT SqlQueryModel : public QStandardItemModel
         void executeQueryInternal();
         void internalExecutionStopped();
         QHash<AliasedTable,TableDetails> readTableDetails();
-        QList<AliasedTable> getTablesForColumns();
-        QList<bool> getColumnEditionEnabledList();
         QList<SqlQueryItem*> toItemList(const QModelIndexList& indexes) const;
         bool commitRow(const QList<SqlQueryItem*>& itemsInRow, QList<CommitSuccessfulHandler>& successfulCommitHandlers);
         void rollbackRow(const QList<SqlQueryItem*>& itemsInRow);
@@ -385,6 +397,7 @@ class GUI_API_EXPORT SqlQueryModel : public QStandardItemModel
         void notifyItemEditionEnded(const QModelIndex& idx);
         int getRowsPerPage() const;
         bool isEmptyQuery() const;
+        void restoreFocusedCell();
 
         QString query;
         QHash<QString, QVariant> queryParams;
@@ -479,19 +492,17 @@ class GUI_API_EXPORT SqlQueryModel : public QStandardItemModel
          */
         int columnRatioBasedRowLimit = -1;
 
-        int resultColumnCount = 0;
-
         /**
          * @brief tablesForColumns
-         * List of tables associated to \link #columns by order index.
+         * Map of queru executor alias to tables associated to \link #columns.
          */
-        QList<AliasedTable> tablesForColumns;
+        QHash<QString,AliasedTable> tablesForColumns;
 
         /**
          * @brief columnEditionStatus
-         * List of column edition capabilities, in the same order as \link #columns.
+         * Map of query executor alias to column edition capabilities.
          */
-        QList<bool> columnEditionStatus;
+        QHash<QString, bool> columnEditionStatus;
 
         QList<int> rowsDeletedSuccessfullyInTheCommit;
 
@@ -522,7 +533,7 @@ class GUI_API_EXPORT SqlQueryModel : public QStandardItemModel
         void prevPage();
         void nextPage();
         void lastPage();
-        void executeQuery();
+        void executeQuery(bool enforcePage0 = false);
         void interrupt();
         void commit();
         void rollback();
