@@ -12,6 +12,8 @@ SqlQueryModelColumn::SqlQueryModelColumn(const QueryExecutor::ResultColumnPtr& r
     database = resultColumn->database.isEmpty() ? "main": resultColumn->database;
     for (QueryExecutor::ColumnEditionForbiddenReason reason : resultColumn->editionForbiddenReasons)
         editionForbiddenReason << SqlQueryModelColumn::convert(reason);
+
+    queryExecutorAlias = resultColumn->queryExecutorAlias;
 }
 
 SqlQueryModelColumn::~SqlQueryModelColumn()
@@ -58,6 +60,8 @@ SqlQueryModelColumn::EditionForbiddenReason SqlQueryModelColumn::convert(QueryEx
             return EditionForbiddenReason::COMMON_TABLE_EXPRESSION;
         case QueryExecutor::ColumnEditionForbiddenReason::VIEW_NOT_EXPANDED:
             return EditionForbiddenReason::VIEW_NOT_EXPANDED;
+        case QueryExecutor::ColumnEditionForbiddenReason::RES_INLINE_SUBSEL:
+            return EditionForbiddenReason::RESULT_INLINE_SUBSELECT;
     }
     return static_cast<EditionForbiddenReason>(-1);
 }
@@ -66,6 +70,8 @@ QString SqlQueryModelColumn::resolveMessage(SqlQueryModelColumn::EditionForbidde
 {
     switch (reason)
     {
+        case SqlQueryModelColumn::EditionForbiddenReason::RESULT_INLINE_SUBSELECT:
+            return QObject::tr("Cannot edit columns that are result of an inline subquery.");
         case EditionForbiddenReason::COMPOUND_SELECT:
             return QObject::tr("Cannot edit columns that are result of compound %1 statements (one that includes %2, %3 or %4 keywords).")
                     .arg("SELECT", "UNION", "INTERSECT", "EXCEPT");
@@ -367,15 +373,10 @@ SqlQueryModelColumn::Constraint* SqlQueryModelColumn::Constraint::create(SqliteC
         }
         case SqliteCreateTable::Column::Constraint::FOREIGN_KEY:
         {
-            if (columnConstraint->foreignKey->indexedColumns.size() == 0)
-            {
-                qWarning() << "No foreign column defined for FK column constraint while creating SqlQueryModelColumn::Constraint.";
-                return nullptr;
-            }
-
             ConstraintFk* fk = new ConstraintFk();
             fk->foreignTable = columnConstraint->foreignKey->foreignTable;
-            fk->foreignColumn = columnConstraint->foreignKey->indexedColumns.first()->name;
+            if (columnConstraint->foreignKey->indexedColumns.size() > 0)
+                fk->foreignColumn = columnConstraint->foreignKey->indexedColumns.first()->name;
 
             constr = fk;
             constr->type = Type::FOREIGN_KEY;
@@ -442,7 +443,10 @@ QString SqlQueryModelColumn::ConstraintFk::getTypeString() const
 
 QString SqlQueryModelColumn::ConstraintFk::getDetails() const
 {
-    return "("+QObject::tr("references table %1, column %2", "data view tooltip").arg(foreignTable).arg(foreignColumn)+")";
+    if (foreignColumn.isNull())
+        return "("+QObject::tr("references table %1", "data view tooltip").arg(foreignTable)+")";
+    else
+        return "("+QObject::tr("references table %1, column %2", "data view tooltip").arg(foreignTable, foreignColumn)+")";
 }
 
 Icon* SqlQueryModelColumn::ConstraintFk::getIcon() const
