@@ -218,7 +218,7 @@ void SqlTableModel::updateRowAfterInsert(const QList<SqlQueryItem*>& itemsInRow,
     int colIdx = 0;
     for (SqlQueryItem* itemToUpdate : itemsInRow)
     {
-        updateItem(itemToUpdate, values[itemToUpdate], colIdx, rowId);
+        updateItem(itemToUpdate, values[itemToUpdate], modelColumns[colIdx], rowId);
 
         if (isWithOutRowIdTable && rowId.isEmpty())
             itemToUpdate->setJustInsertedWithOutRowId(true);
@@ -355,10 +355,10 @@ void SqlTableModel::updateColumnsAndValues(const QList<SqlQueryItem*>& itemsInRo
     int i = 0;
     for (SqlQueryModelColumnPtr modelColumn : modelColumns)
     {
+        item = itemsInRow[i++];
         if (!modelColumn->canEdit())
             continue;
 
-        item = itemsInRow[i++];
         if (item->getValue().isNull())
         {
             if (CFG_UI.General.UseDefaultValueForNull.get() && modelColumn->isDefault())
