@@ -97,7 +97,7 @@ void DbTree::init()
     treeModel = new DbTreeModel();
     treeModel->setTreeView(ui->treeView);
 
-    new UserInputFilter(ui->nameFilter, treeModel, SLOT(applyFilter(QString)));
+    new UserInputFilter(ui->nameFilter, treeModel, SLOT(applyFilter(QString)), true);
 
     ui->treeView->setDbTree(this);
     ui->treeView->setModel(treeModel);
@@ -119,6 +119,7 @@ void DbTree::init()
     connect(treeModel, SIGNAL(rowsInserted(QModelIndex,int,int)), this, SIGNAL(sessionValueChanged()));
     connect(treeModel, SIGNAL(rowsMoved(QModelIndex,int,int,QModelIndex,int)), this, SIGNAL(sessionValueChanged()));
     connect(treeModel, SIGNAL(rowsRemoved(QModelIndex,int,int)), this, SIGNAL(sessionValueChanged()));
+    connect(treeModel, &DbTreeModel::filteringInterrupted, this, &DbTree::resetFilterValueAfterInterrupting);
     connect(ui->treeView, SIGNAL(expanded(QModelIndex)), this, SIGNAL(sessionValueChanged()));
     connect(ui->treeView, SIGNAL(collapsed(QModelIndex)), this, SIGNAL(sessionValueChanged()));
 
@@ -221,6 +222,7 @@ void DbTree::updateActionStates(const QStandardItem *item)
             switch (dbTreeItem->getType())
             {
                 case DbTreeItem::Type::ITEM_PROTOTYPE:
+                case DbTreeItem::Type::SIGNATURE_OF_THIS:
                     break;
                 case DbTreeItem::Type::DIR:
                     // It's handled outside of "item with db", above
@@ -317,10 +319,11 @@ void DbTree::updateActionStates(const QStandardItem *item)
                     break;
                 case DbTreeItem::Type::COLUMNS:
                 case DbTreeItem::Type::INDEXES:
-                case DbTreeItem::Type::ITEM_PROTOTYPE:
                 case DbTreeItem::Type::TABLES:
                 case DbTreeItem::Type::TRIGGERS:
                 case DbTreeItem::Type::VIEWS:
+                case DbTreeItem::Type::ITEM_PROTOTYPE:
+                case DbTreeItem::Type::SIGNATURE_OF_THIS:
                     break;
             }
 
@@ -575,6 +578,7 @@ void DbTree::setupActionsForMenu(DbTreeItem* currItem, QMenu* contextMenu)
                 actions += dbEntryExt;
                 break;
             case DbTreeItem::Type::ITEM_PROTOTYPE:
+            case DbTreeItem::Type::SIGNATURE_OF_THIS:
                 break;
         }
 
@@ -646,12 +650,18 @@ void DbTree::initDndTypes()
 QVariant DbTree::saveSession()
 {
     treeModel->storeGroups();
-    return QVariant();
+
+    QHash<QString, QVariant> session;
+    session["selectionState"] = treeModel->collectSelectionState();
+    return session;
 }
 
 void DbTree::restoreSession(const QVariant& sessionValue)
 {
-    UNUSED(sessionValue);
+    QHash<QString, QVariant> session = sessionValue.toHash();
+    QHash<QString, QVariant> selectionState = session["selectionState"].toHash();
+    if (!selectionState.isEmpty())
+        treeModel->restoreSelectionState(selectionState);
 }
 
 DbTreeModel* DbTree::getModel() const
@@ -659,7 +669,7 @@ DbTreeModel* DbTree::getModel() const
     return treeModel;
 }
 
-DbTreeView*DbTree::getView() const
+DbTreeView* DbTree::getView() const
 {
     return ui->treeView;
 }
@@ -878,6 +888,7 @@ void DbTree::filterUndeletableItems(QList<DbTreeItem*>& items)
             case DbTreeItem::Type::VIEWS:
             case DbTreeItem::Type::COLUMNS:
             case DbTreeItem::Type::ITEM_PROTOTYPE:
+            case DbTreeItem::Type::SIGNATURE_OF_THIS:
                 it.remove();
                 break;
             case DbTreeItem::Type::DIR:
@@ -942,6 +953,7 @@ void DbTree::deleteItem(DbTreeItem* item)
         case DbTreeItem::Type::COLUMNS:
         case DbTreeItem::Type::COLUMN:
         case DbTreeItem::Type::ITEM_PROTOTYPE:
+        case DbTreeItem::Type::SIGNATURE_OF_THIS:
             return;
     }
 
@@ -1820,6 +1832,11 @@ void DbTree::decrFontSize()
     changeFontSize(-1);
 }
 
+void DbTree::resetFilterValueAfterInterrupting()
+{
+    ui->nameFilter->clear();
+}
+
 void DbTree::dbConnected(Db* db)
 {
     updateActionsForCurrent();
