@@ -24,6 +24,7 @@
 #include <QCheckBox>
 #include <QWidgetAction>
 #include <QClipboard>
+#include <QElapsedTimer>
 
 const QString DbTreeModel::toolTipTableTmp = "<table>%1</table>";
 const QString DbTreeModel::toolTipHdrRowTmp = "<tr><th><img src=\"%1\"/></th><th colspan=2>%2</th></tr>";
@@ -130,27 +131,63 @@ QStringList DbTreeModel::getGroupFor(QStandardItem *item)
 void DbTreeModel::applyFilter(const QString &filter)
 {
     applyFilter(root(), filter);
-    currentFilter = filter;
 }
 
-bool DbTreeModel::applyFilter(QStandardItem *parentItem, const QString &filter)
+void DbTreeModel::applyFilter(QStandardItem *parentItem, const QString &filter)
+{
+    if (filteringInProgress) // already processing the (possibly interrupted) filtering - ssubsequent call is possible after filter edit field is cleared
+        return;
+
+    filteringInProgress = new ItemFiltering();
+    interruptableStarted(filteringInProgress);
+
+    applyFilterRecursively(parentItem, filter);
+    currentFilter = filter;
+
+    if (filteringInProgress->interrupted)
+    {
+        applyFilterRecursively(parentItem, "");
+        currentFilter = "";
+        emit filteringInterrupted();
+    }
+    interruptableFinished(filteringInProgress);
+
+    safe_delete(filteringInProgress);
+}
+
+bool DbTreeModel::applyFilterRecursively(QStandardItem *parentItem, const QString &filter)
 {
     bool empty = filter.isEmpty();
-    bool visibilityForParent = false;
-    DbTreeItem* item = nullptr;
-    QModelIndex index;
-    bool subFilterResult;
-    bool matched;
+    bool visibilityForParent = filteringInProgress->interrupted; // if interrupted, this is true by default, otherwise it's false at start and calculated later
     for (int i = 0; i < parentItem->rowCount(); i++)
     {
-         item = dynamic_cast<DbTreeItem*>(parentItem->child(i));
-         index = item->index();
-         subFilterResult = applyFilter(item, filter);
-         matched = empty || subFilterResult || item->text().contains(filter, Qt::CaseInsensitive);
-         treeView->setRowHidden(index.row(), index.parent(), !matched);
+        DbTreeItem* item = dynamic_cast<DbTreeItem*>(parentItem->child(i));
+        if (filteringInProgress->interrupted)
+        {
+            applyFilterRecursively(item, filter);
+            QModelIndex index = item->index();
+            treeView->setRowHidden(index.row(), index.parent(), false);
+            continue;
+        }
 
-         if (matched)
-             visibilityForParent = true;
+        if (!filter.isEmpty())
+        {
+            if (item->getType() == DbTreeItem::Type::TABLE)
+                loadTableSchema(item);
+            else if (item->getType() == DbTreeItem::Type::VIEW)
+                loadViewSchema(item);
+        }
+
+        QModelIndex index = item->index();
+        bool subFilterResult = applyFilterRecursively(item, filter);
+        bool matched = empty || subFilterResult || item->text().contains(filter, Qt::CaseInsensitive);
+        treeView->setRowHidden(index.row(), index.parent(), !matched);
+
+        if (matched)
+            visibilityForParent = true;
+
+        if (i % 10 == 9)
+            qApp->processEvents();
     }
     return visibilityForParent;
 }
@@ -280,7 +317,14 @@ void DbTreeModel::expanded(const QModelIndex &index)
         return;
     }
 
-    if (dynamic_cast<DbTreeItem*>(item)->getType() == DbTreeItem::Type::DIR)
+    DbTreeItem* dbTreeItem = dynamic_cast<DbTreeItem*>(item);
+    if (dbTreeItem->getType() == DbTreeItem::Type::TABLE)
+        loadTableSchema(dbTreeItem);
+
+    if (dbTreeItem->getType() == DbTreeItem::Type::VIEW)
+        loadViewSchema(dbTreeItem);
+
+    if (dbTreeItem->getType() == DbTreeItem::Type::DIR)
         itemFromIndex(index)->setIcon(ICONS.DIRECTORY_OPEN);
 }
 
@@ -341,7 +385,8 @@ void DbTreeModel::dbRemoved(QStandardItem* item)
 
 void DbTreeModel::interrupt()
 {
-    dbOrganizer->interrupt();
+    for (Interruptable* i : interruptables)
+        i->interrupt();
 }
 
 void DbTreeModel::refreshSchema(Db* db)
@@ -443,8 +488,9 @@ QString DbTreeModel::getDbToolTip(DbTreeItem* item) const
 
 QString DbTreeModel::getTableToolTip(DbTreeItem* item) const
 {
-    QStringList rows;
+    const_cast<DbTreeModel*>(this)->loadTableSchema(item); // not nice to const_cast, but nothing better we can do about this
 
+    QStringList rows;
     rows << toolTipHdrRowTmp.arg(ICONS.TABLE.getPath()).arg(tr("Table : %1", "dbtree tooltip").arg(item->text()));
 
     QStandardItem* columnsItem = item->child(0);
@@ -489,6 +535,9 @@ void DbTreeModel::refreshSchema(Db* db, QStandardItem *item)
     QHash<QString, bool> expandedState;
     collectExpandedState(expandedState, item);
 
+    // Remember selection state
+    QHash<QString, QVariant> selectionState = collectSelectionState();
+
     // Delete child nodes
     while (item->rowCount() > 0)
         item->removeRow(0);
@@ -499,22 +548,36 @@ void DbTreeModel::refreshSchema(Db* db, QStandardItem *item)
 
     // Collect all db objects and build the db branch
     bool sort = CFG_UI.General.SortObjects.get();
-    QStringList tables = resolver.getTables();
-    QStringList virtualTables;
-    for (const QString& table : tables)
+    QList<SchemaResolver::TableListItem> tableListItems = resolver.getAllTableListItems();
+    QStringList tables;
+    QStringList views;
+    QSet<QString> virtualTables;
+
+    for (SchemaResolver::TableListItem& tableListItem : tableListItems)
     {
-        if (resolver.isVirtualTable(table))
-            virtualTables << table;
+        switch (tableListItem.type)
+        {
+            case SchemaResolver::TableListItem::VIRTUAL_TABLE:
+                virtualTables << tableListItem.name;
+                [[fallthrough]];
+            case SchemaResolver::TableListItem::TABLE:
+            case SchemaResolver::TableListItem::SHADOW_TABLE:
+                tables << tableListItem.name;
+                break;
+            case SchemaResolver::TableListItem::VIEW:
+                views << tableListItem.name;
+                break;
+            case SchemaResolver::TableListItem::UNKNOWN:
+                break;
+        }
     }
 
     QList<QStandardItem*> tableItems = refreshSchemaTables(tables, virtualTables, sort);
-    StrHash<QList<QStandardItem*>> allTableColumns = refreshSchemaTableColumns(resolver.getAllTableColumns());
-    StrHash<QList<QStandardItem*>> indexItems = refreshSchemaIndexes(resolver.getGroupedIndexes(), sort);
-    StrHash<QList<QStandardItem*>> triggerItems = refreshSchemaTriggers(resolver.getGroupedTriggers(), sort);
-    QList<QStandardItem*> viewItems = refreshSchemaViews(resolver.getViews(), sort);
-    refreshSchemaBuild(item, tableItems, indexItems, triggerItems, viewItems, allTableColumns);
+    QList<QStandardItem*> viewItems = refreshSchemaViews(views, sort);
+    refreshSchemaBuild(item, tableItems, viewItems);
     populateChildItemsWithDb(item, db);
     restoreExpandedState(expandedState, item);
+    restoreSelectionState(selectionState);
 }
 
 void DbTreeModel::collectExpandedState(QHash<QString, bool> &state, QStandardItem *parentItem)
@@ -524,13 +587,13 @@ void DbTreeModel::collectExpandedState(QHash<QString, bool> &state, QStandardIte
 
     DbTreeItem* dbTreeItem = dynamic_cast<DbTreeItem*>(parentItem);
     if (dbTreeItem)
-        state[dbTreeItem->signature()] = treeView->isExpanded(dbTreeItem->index());
+        state[dbTreeItem->pathSignature()] = treeView->isExpanded(dbTreeItem->index());
 
     for (int i = 0; i < parentItem->rowCount(); i++)
         collectExpandedState(state, parentItem->child(i));
 }
 
-QList<QStandardItem *> DbTreeModel::refreshSchemaTables(const QStringList &tables, const QStringList& virtualTables, bool sort)
+QList<QStandardItem *> DbTreeModel::refreshSchemaTables(const QStringList &tables, const QSet<QString>& virtualTables, bool sort)
 {
     QStringList sortedTables = tables;
     if (sort)
@@ -548,52 +611,44 @@ QList<QStandardItem *> DbTreeModel::refreshSchemaTables(const QStringList &table
     return items;
 }
 
-StrHash<QList<QStandardItem*>> DbTreeModel::refreshSchemaTableColumns(const StrHash<QStringList> &columns)
+QList<QStandardItem*> DbTreeModel::refreshSchemaTableColumns(const QStringList& columns)
 {
-    QStringList sortedColumns;
     bool doSort = CFG_UI.General.SortColumns.get();
-    StrHash<QList<QStandardItem*>> items;
-    for (const QString& key : columns.keys())
-    {
-        sortedColumns = columns[key];
-        if (doSort)
-            ::sSort(sortedColumns);
 
-        for (const QString& column : sortedColumns)
-            items[key] += DbTreeItemFactory::createColumn(column, this);
-    }
+    QStringList sortedColumns = columns;
+    if (doSort)
+        ::sSort(sortedColumns);
+
+    QList<QStandardItem*> items;
+    for (const QString& column : sortedColumns)
+        items += DbTreeItemFactory::createColumn(column, this);
+
     return items;
 }
 
-StrHash<QList<QStandardItem *> > DbTreeModel::refreshSchemaIndexes(const StrHash<QStringList> &indexes, bool sort)
+QList<QStandardItem*> DbTreeModel::refreshSchemaIndexes(const QStringList& indexes, bool sort)
 {
-    StrHash<QList<QStandardItem *> > items;
-    QStringList sortedIndexes;
-    for (const QString& key : indexes.keys())
-    {
-        sortedIndexes = indexes[key];
-        if (sort)
-            sortedIndexes.sort(Qt::CaseInsensitive);
+    QStringList sortedIndexes = indexes;
+    if (sort)
+        sortedIndexes.sort(Qt::CaseInsensitive);
+
+    QList<QStandardItem*> items;
+    for (const QString& index : sortedIndexes)
+        items += DbTreeItemFactory::createIndex(index, this);
 
-        for (const QString& index : sortedIndexes)
-            items[key] += DbTreeItemFactory::createIndex(index, this);
-    }
     return items;
 }
 
-StrHash<QList<QStandardItem*>> DbTreeModel::refreshSchemaTriggers(const StrHash<QStringList> &triggers, bool sort)
+QList<QStandardItem*> DbTreeModel::refreshSchemaTriggers(const QStringList& triggers, bool sort)
 {
-    StrHash<QList<QStandardItem*>> items;
-    QStringList sortedTriggers;
-    for (const QString& key : triggers.keys())
-    {
-        sortedTriggers = triggers[key];
-        if (sort)
-            sortedTriggers.sort(Qt::CaseInsensitive);
+    QStringList sortedTriggers = triggers;
+    if (sort)
+        sortedTriggers.sort(Qt::CaseInsensitive);
+
+    QList<QStandardItem*> items;
+    for (const QString& trigger : sortedTriggers)
+        items += DbTreeItemFactory::createTrigger(trigger, this);
 
-        for (const QString& trigger : sortedTriggers)
-            items[key] += DbTreeItemFactory::createTrigger(trigger, this);
-    }
     return items;
 }
 
@@ -621,12 +676,70 @@ void DbTreeModel::populateChildItemsWithDb(QStandardItem *parentItem, Db* db)
     }
 }
 
+void DbTreeModel::loadTableSchema(DbTreeItem* tableItem)
+{
+    if (tableItem->isSchemaReady())
+        return;
+
+    Db* db = tableItem->getDb();
+    QString table = tableItem->text();
+
+    SchemaResolver resolver(db);
+    resolver.setIgnoreSystemObjects(!CFG_UI.General.ShowSystemObjects.get());
+
+    bool sort = CFG_UI.General.SortObjects.get();
+
+    DbTreeItem* columnsItem = tableItem->findFirstItem(DbTreeItem::Type::COLUMNS);
+    DbTreeItem* indexesItem = tableItem->findFirstItem(DbTreeItem::Type::INDEXES);
+    DbTreeItem* triggersItem = tableItem->findFirstItem(DbTreeItem::Type::TRIGGERS);
+
+    QList<QStandardItem*> tableColumns = refreshSchemaTableColumns(resolver.getTableColumns(table));
+    QList<QStandardItem*> indexItems = refreshSchemaIndexes(resolver.getIndexesForTable(table), sort);
+    QList<QStandardItem*> triggerItems = refreshSchemaTriggers(resolver.getTriggersForTable(table), sort);
+
+    for (QStandardItem* columnItem : tableColumns)
+        columnsItem->appendRow(columnItem);
+
+    for (QStandardItem* indexItem : indexItems)
+        indexesItem->appendRow(indexItem);
+
+    for (QStandardItem* triggerItem : triggerItems)
+        triggersItem->appendRow(triggerItem);
+
+    populateChildItemsWithDb(columnsItem, db);
+    populateChildItemsWithDb(indexesItem, db);
+    populateChildItemsWithDb(triggersItem, db);
+
+    tableItem->setSchemaReady(true);
+}
+
+void DbTreeModel::loadViewSchema(DbTreeItem* viewItem)
+{
+    if (viewItem->isSchemaReady())
+        return;
+
+    Db* db = viewItem->getDb();
+    QString view = viewItem->text();
+
+    SchemaResolver resolver(db);
+    resolver.setIgnoreSystemObjects(!CFG_UI.General.ShowSystemObjects.get());
+
+    bool sort = CFG_UI.General.SortObjects.get();
+
+    DbTreeItem* triggersItem = viewItem->findFirstItem(DbTreeItem::Type::TRIGGERS);
+
+    QList<QStandardItem*> triggerItems = refreshSchemaTriggers(resolver.getTriggersForView(view), sort);
+    for (QStandardItem* triggerItem : triggerItems)
+        triggersItem->appendRow(triggerItem);
+
+    populateChildItemsWithDb(triggersItem, db);
+
+    viewItem->setSchemaReady(true);
+}
+
 void DbTreeModel::refreshSchemaBuild(QStandardItem *dbItem,
                                      QList<QStandardItem*> tables,
-                                     StrHash<QList<QStandardItem*> > indexes,
-                                     StrHash<QList<QStandardItem*> > triggers,
-                                     QList<QStandardItem*> views,
-                                     StrHash<QList<QStandardItem*> > allTableColumns)
+                                     QList<QStandardItem*> views)
 {
     DbTreeItem* tablesItem = DbTreeItemFactory::createTables(this);
     DbTreeItem* viewsItem = DbTreeItemFactory::createViews(this);
@@ -649,14 +762,7 @@ void DbTreeModel::refreshSchemaBuild(QStandardItem *dbItem,
         tableItem->appendRow(indexesItem);
         tableItem->appendRow(triggersItem);
 
-        for (QStandardItem* columnItem : allTableColumns[tableItem->text()])
-            columnsItem->appendRow(columnItem);
-
-        for (QStandardItem* indexItem : indexes[tableItem->text()])
-            indexesItem->appendRow(indexItem);
-
-        for (QStandardItem* triggerItem : triggers[tableItem->text()])
-            triggersItem->appendRow(triggerItem);
+        dynamic_cast<DbTreeItem*>(tableItem)->setSchemaReady(false);
     }
     for (QStandardItem* viewItem : views)
     {
@@ -664,15 +770,15 @@ void DbTreeModel::refreshSchemaBuild(QStandardItem *dbItem,
 
         triggersItem = DbTreeItemFactory::createTriggers(this);
         viewItem->appendRow(triggersItem);
-        for (QStandardItem* triggerItem : triggers[viewItem->text()])
-            triggersItem->appendRow(triggerItem);
+
+        dynamic_cast<DbTreeItem*>(viewItem)->setSchemaReady(false);
     }
 }
 
 void DbTreeModel::restoreExpandedState(const QHash<QString, bool>& expandedState, QStandardItem* parentItem)
 {
     DbTreeItem* parentDbTreeItem = dynamic_cast<DbTreeItem*>(parentItem);
-    QString sig = parentDbTreeItem->signature();
+    QString sig = parentDbTreeItem->pathSignature();
     if (expandedState.contains(sig) && expandedState[sig])
         treeView->expand(parentItem->index());
 
@@ -680,22 +786,6 @@ void DbTreeModel::restoreExpandedState(const QHash<QString, bool>& expandedState
         restoreExpandedState(expandedState, child);
 }
 
-DbTreeItem* DbTreeModel::findFirstItemOfType(DbTreeItem::Type type, QStandardItem* parentItem)
-{
-    DbTreeItem* child = nullptr;
-    for (int i = 0; i < parentItem->rowCount(); i++)
-    {
-        child = dynamic_cast<DbTreeItem*>(parentItem->child(i));
-        if (child->getType() == type)
-            return child;
-
-        child = findFirstItemOfType(type, child);
-        if (child)
-            return child;
-    }
-    return nullptr;
-}
-
 void DbTreeModel::dbConnected(Db* db, bool expandItem)
 {
     QStandardItem* item = findItem(DbTreeItem::Type::DB, db);
@@ -819,17 +909,16 @@ DbTreeItem *DbTreeModel::findItem(DbTreeItem::Type type, Db* db)
 
 DbTreeItem* DbTreeModel::findFirstItemOfType(DbTreeItem::Type type)
 {
-    return findFirstItemOfType(type, root());
+    return findFirstItem(root(), type);
 }
 
-DbTreeItem *DbTreeModel::findItemBySignature(const QString &signature)
+DbTreeItem *DbTreeModel::findItemBySignature(const QStringList &signature)
 {
-    QStringList parts = signature.split("_");
     QStringList pair;
     DbTreeItem* currItem = nullptr;
     DbTreeItem::Type type;
     QString name;
-    for (const QString& part : parts)
+    for (const QString& part : signature)
     {
         pair = part.split(".");
         type = static_cast<DbTreeItem::Type>(pair.first().toInt());
@@ -883,7 +972,7 @@ QList<DbTreeItem*> DbTreeModel::findItems(QStandardItem* parentItem, DbTreeItem:
         item = dynamic_cast<DbTreeItem*>(parentItem->child(i));
 
         // Search recursively
-        if (item->getType() == DbTreeItem::Type::DIR)
+        if (item->hasChildren())
             items += findItems(item, type);
 
         if (item->getType() != type)
@@ -895,6 +984,28 @@ QList<DbTreeItem*> DbTreeModel::findItems(QStandardItem* parentItem, DbTreeItem:
     return items;
 }
 
+DbTreeItem* DbTreeModel::findFirstItem(QStandardItem* parentItem, DbTreeItem::Type type)
+{
+    for (int i = 0; i < parentItem->rowCount(); i++)
+    {
+        DbTreeItem* item = dynamic_cast<DbTreeItem*>(parentItem->child(i));
+
+        if (item->hasChildren())
+        {
+            DbTreeItem* child = findFirstItem(item, type);
+            if (child)
+                return child;
+        }
+
+        if (item->getType() != type)
+            continue;
+
+        return item;
+    }
+
+    return nullptr;
+}
+
 QStandardItem* DbTreeModel::root() const
 {
     return invisibleRootItem();
@@ -942,11 +1053,12 @@ QMimeData *DbTreeModel::mimeData(const QModelIndexList &indexes) const
     QStringList textList;
 
     DbTreeItem* item = nullptr;
-    stream << reinterpret_cast<qint32>(indexes.size());
+    qint32 indexesSize = indexes.size();
+    stream << indexesSize;
     for (const QModelIndex& idx : indexes)
     {
         item = dynamic_cast<DbTreeItem*>(itemFromIndex(idx));
-        stream << item->signature();
+        stream << item->pathSignatureParts();
 
         textList << item->text();
         if (item->getType() == DbTreeItem::Type::DB)
@@ -1021,7 +1133,7 @@ QList<DbTreeItem*> DbTreeModel::getDragItems(const QMimeData* data)
     stream >> itemCount;
 
     DbTreeItem* item = nullptr;
-    QString signature;
+    QStringList signature;
     for (qint32 i = 0; i < itemCount; i++)
     {
         stream >> signature;
@@ -1045,6 +1157,38 @@ QList<DbTreeItem*> DbTreeModel::getItemsForIndexes(const QModelIndexList& indexe
     return items;
 }
 
+QHash<QString, QVariant> DbTreeModel::collectSelectionState()
+{
+    DbTreeItem* activeItem = treeView->currentItem();
+    QStringList currentItem = activeItem ? activeItem->pathSignatureParts() : QStringList();
+    QList<QVariant> selectedItems = map<DbTreeItem*, QVariant>(treeView->selectionItems(), [](auto item) {return item->pathSignatureParts();});
+
+    QHash<QString, QVariant> selectionState;
+    selectionState["currentItem"] = currentItem;
+    selectionState["selectedItems"] = selectedItems;
+    return selectionState;
+}
+
+void DbTreeModel::restoreSelectionState(const QHash<QString, QVariant>& selectionState)
+{
+    QHash<QStringList, DbTreeItem*> allItemMap = getAllItemsWithSignatures();
+
+    // Current/Active
+    QStringList currentSig = selectionState["currentItem"].toStringList();
+    DbTreeItem* currentItem = findDeepestExistingItemBySignature(currentSig, allItemMap);
+    if (currentItem)
+        treeView->setCurrentItem(currentItem);
+
+    // Selected items
+    QList<QStringList> selectedSignatures = map<QVariant, QStringList>(selectionState["selectedItems"].toList(), [](const QVariant& v) {return v.toStringList();});
+    QList<DbTreeItem*> selectedItems = map<QStringList, DbTreeItem*>(selectedSignatures, [&allItemMap, this](const QStringList& sig)
+    {
+        return findDeepestExistingItemBySignature(sig, allItemMap);
+    });
+    selectedItems = filter<DbTreeItem*>(selectedItems, [](DbTreeItem* item) {return !!item;});
+    treeView->selectItems(selectedItems);
+}
+
 void DbTreeModel::staticInit()
 {
 }
@@ -1090,6 +1234,7 @@ bool DbTreeModel::dropDbTreeItem(const QList<DbTreeItem*>& srcItems, DbTreeItem*
         case DbTreeItem::Type::COLUMNS:
         case DbTreeItem::Type::VIRTUAL_TABLE:
         case DbTreeItem::Type::ITEM_PROTOTYPE:
+        case DbTreeItem::Type::SIGNATURE_OF_THIS:
             break;
     }
 
@@ -1232,6 +1377,23 @@ void DbTreeModel::moveOrCopyDbObjects(const QList<DbTreeItem*>& srcItems, DbTree
         dbOrganizer->copyObjectsToDb(srcDb, srcNames, dstDb, includeData, includeIndexes, includeTriggers);
 }
 
+QHash<QStringList, DbTreeItem*> DbTreeModel::getAllItemsWithSignatures() const
+{
+    QList<DbTreeItem*> allItems = getAllItemsAsFlatList();
+    return toHash<QStringList, DbTreeItem*>(allItems, [](DbTreeItem* item) {return item->pathSignatureParts();});
+}
+
+DbTreeItem* DbTreeModel::findDeepestExistingItemBySignature(QStringList signature, const QHash<QStringList, DbTreeItem*>& allItemsWithSignatures) const
+{
+    DbTreeItem* item = allItemsWithSignatures[signature];
+    while (!item && !signature.isEmpty())
+    {
+        signature.removeLast();
+        item = allItemsWithSignatures[signature];
+    }
+    return item;
+}
+
 bool DbTreeModel::confirmReferencedTables(const QStringList& tables)
 {
     QMessageBox::StandardButton result = QMessageBox::question(MAINWINDOW, tr("Referenced tables"),
