@@ -32,11 +32,14 @@ class GUI_API_EXPORT IconManager : public QObject
             DEF_ICON(APPLY_FILTER_RE,                   "apply_filter_re")
             DEF_ICON(APPLY_FILTER_SQL,                  "apply_filter_sql")
             DEF_ICON(APPLY_FILTER_TXT,                  "apply_filter_txt")
+            DEF_ICON(APPLY_FILTER_TXT_STRICT,           "apply_filter_txt_strict")
             DEF_ICON(BUG,                               "bug")
             DEF_ICON(BUG_LIST,                          "bug_list")
             DEF_ICON(CLEAR_HISTORY,                     "clear_history")
             DEF_ICON(CLEAR_LINEEDIT,                    "clear_lineedit")
             DEF_ICON(CLOSE,                             "close")
+            DEF_ICON(CODE_ASSISTANT,                    "code_assistant")
+            DEF_ICON(CODE_SNIPPET,                      "code_snippet")
             DEF_ICON(COLUMN,                            "column")
             DEF_ICON(COLUMN_CONSTRAINT,                 "column_constraint")
             DEF_ICO2(COLUMN_CONSTRAINT_ADD,             COLUMN_CONSTRAINT, PLUS)
@@ -142,8 +145,6 @@ class GUI_API_EXPORT IconManager : public QObject
             DEF_ICON(KEYWORD,                           "keyword")
             DEF_ICON(LICENSES,                          "licenses")
             DEF_ICON(LOADING,                           "loading")
-            DEF_ICON(LOAD_FULL_VALUE,                   "load_full_value")
-            DEF_ICON(LOAD_FULL_VALUES,                  "load_full_values")
             DEF_ICON(MOVE_DOWN,                         "move_down")
             DEF_ICON(MOVE_UP,                           "move_up")
             DEF_ICO3(NEW_COLLATION,                     INSERT_ROW)
@@ -164,6 +165,7 @@ class GUI_API_EXPORT IconManager : public QObject
             DEF_ICON(RENAME_FN_ARG,                     "rename_fn_arg")
             DEF_ICO3(RENAME_DATATYPE,                   RENAME_FN_ARG)
             DEF_ICON(RESET_AUTOINCREMENT,               "reset_autoincrement")
+            DEF_ICON(RESTORE_DEFAULT,                   "restore_default")
             DEF_ICON(RESULTS_BELOW,                     "results_below")
             DEF_ICON(RESULTS_IN_TAB,                    "results_in_tab")
             DEF_ICON(ROLLBACK,                          "rollback")
@@ -171,6 +173,7 @@ class GUI_API_EXPORT IconManager : public QObject
             DEF_ICON(SAVE_SQL_FILE,                     "save_sql_file")
             DEF_ICON(SEARCH,                            "search")
             DEF_ICON(SEARCH_AND_REPLACE,                "search_and_replace")
+            DEF_ICON(SELECTION_INVERT,                  "selection_invert")
             DEF_ICON(SET_NULL,                          "set_null")
             DEF_ICON(SORT_COLUMNS,                      "sort_columns")
             DEF_ICON(SORT_COUNT_01,                     "sort_cnt_01")
@@ -241,6 +244,8 @@ class GUI_API_EXPORT IconManager : public QObject
             DEF_ICON(WIN_TILE_VERTICAL,                 "win_tile_vertical")
             DEF_ICON(WIN_CLOSE,                         "window_close")
             DEF_ICON(WIN_CLOSE_ALL,                     "window_close_all")
+            DEF_ICON(WIN_CLOSE_ALL_LEFT,                "window_close_all_left")
+            DEF_ICON(WIN_CLOSE_ALL_RIGHT,               "window_close_all_right")
             DEF_ICON(WIN_CLOSE_OTHER,                   "window_close_other")
             DEF_ICON(WIN_RESTORE,                       "window_restore")
             DEF_ICON(WIN_RENAME,                        "window_rename")
